@@ -52,6 +52,10 @@ struct _XfcePanelPluginProviderInterface
   gint         (*get_unique_id)       (XfcePanelPluginProvider       *provider);
   void         (*set_size)            (XfcePanelPluginProvider       *provider,
                                        gint                           size);
+  void         (*set_icon_size)       (XfcePanelPluginProvider       *provider,
+                                       gint                           icon_size);
+  void         (*set_dark_mode)       (XfcePanelPluginProvider       *provider,
+                                       gboolean                       dark_mode);
   void         (*set_mode)            (XfcePanelPluginProvider       *provider,
                                        XfcePanelPluginMode            mode);
   void         (*set_nrows)           (XfcePanelPluginProvider       *provider,
@@ -101,13 +105,14 @@ XfcePanelPluginProviderSignal;
 typedef enum /*< skip >*/
 {
   PROVIDER_PROP_TYPE_SET_SIZE,                /* gint */
+  PROVIDER_PROP_TYPE_SET_ICON_SIZE,           /* gint */
+  PROVIDER_PROP_TYPE_SET_DARK_MODE,           /* gboolean */
   PROVIDER_PROP_TYPE_SET_MODE,                /* XfcePanelPluginMode (as gint) */
   PROVIDER_PROP_TYPE_SET_SCREEN_POSITION,     /* XfceScreenPosition (as gint) */
   PROVIDER_PROP_TYPE_SET_BACKGROUND_ALPHA,    /* gdouble */
   PROVIDER_PROP_TYPE_SET_NROWS,               /* gint */
   PROVIDER_PROP_TYPE_SET_LOCKED,              /* gboolean */
   PROVIDER_PROP_TYPE_SET_SENSITIVE,           /* gboolean */
-  PROVIDER_PROP_TYPE_SET_OPACITY,             /* gdouble */
   PROVIDER_PROP_TYPE_SET_BACKGROUND_COLOR,    /* string, wrapper only */
   PROVIDER_PROP_TYPE_SET_BACKGROUND_IMAGE,    /* string, wrapper only */
   PROVIDER_PROP_TYPE_ACTION_REMOVED,          /* none */
@@ -117,7 +122,8 @@ typedef enum /*< skip >*/
   PROVIDER_PROP_TYPE_ACTION_BACKGROUND_UNSET, /* none */
   PROVIDER_PROP_TYPE_ACTION_SHOW_CONFIGURE,   /* none */
   PROVIDER_PROP_TYPE_ACTION_SHOW_ABOUT,       /* none */
-  PROVIDER_PROP_TYPE_ACTION_ASK_REMOVE        /* none */
+  PROVIDER_PROP_TYPE_ACTION_ASK_REMOVE,       /* none */
+  PROVIDER_PROP_TYPE_SET_OPACITY              /* gdouble */
 }
 XfcePanelPluginProviderPropType;
 
@@ -143,7 +149,6 @@ enum
   PLUGIN_ARGV_NAME,
   PLUGIN_ARGV_DISPLAY_NAME,
   PLUGIN_ARGV_COMMENT,
-  PLUGIN_ARGV_BACKGROUND_IMAGE,
   PLUGIN_ARGV_ARGUMENTS
 };
 
@@ -158,6 +163,12 @@ gint                  xfce_panel_plugin_provider_get_unique_id       (XfcePanelP
 void                  xfce_panel_plugin_provider_set_size            (XfcePanelPluginProvider       *provider,
                                                                       gint                           size);
 
+void                  xfce_panel_plugin_provider_set_icon_size       (XfcePanelPluginProvider       *provider,
+                                                                      gint                           icon_size);
+
+void                  xfce_panel_plugin_provider_set_dark_mode       (XfcePanelPluginProvider       *provider,
+                                                                      gboolean                       dark_mode);
+
 void                  xfce_panel_plugin_provider_set_mode            (XfcePanelPluginProvider       *provider,
                                                                       XfcePanelPluginMode            mode);
 
